@@ -2,12 +2,10 @@
 
 from __future__ import annotations
 
-from .launch_agent import launch_agent
+from .agent_dispatch import dispatch_agent
 from .provision import provision_subagents
-from .transpiler import transpile_subagent
 
 __all__ = [
-    "launch_agent",
+    "dispatch_agent",
     "provision_subagents",
-    "transpile_subagent",
 ]
